Ajustes relativos ao Pregão

# Ajustes do Pregão

Retroativo: |  |
Legenda
Cód. | Mês
F | Janeiro
G | Fevereiro
H | Março
J | Abril
K | Maio
M | Junho
Cód. | Mês
N | Julho
Q | Agosto
U | Setembro
V | Outubro
X | Novembro
Z | Dezembro

Mercadoria | Vct | Preço de Ajuste Anterior | Preço de Ajuste Atual | Variação | Valor do Ajuste por Contrato (R$)
Não há dados para a data consultada.

(*) O PREÇO ANTERIOR JÁ ESTÁ CORRIGIDO PELA TAXA CETIP PARA DI1;
PELA DIFERENÇA ENTRE TAXA CETIP E VARIAÇÃO DO DÓLAR PARA DDI;
PELA DIFERENÇA ENTRE TAXA CETIP E VARIAÇÃO DO IGP-M; PARA DDM;
PELA DIFERENÇA ENTRE TAXA CETIP E VARIAÇÃO DO IPCA PARA DAP.
OBS.: AS TAXAS DE CÂMBIO UTILIZADAS SEGUEM AS ESPECIFICAÇÕES CONTRATUAIS